#!/usr/bin/env python

# Convert XaoS cat file to Java properties file

import fileinput

key = None
for line in fileinput.input():
    line = line.strip('\r\n')
    if key is None:
        # we are not in the middle of a multiline value
        strip = line.strip()
        if len(strip) == 0 or strip.startswith('#'):
            # print comments and blank lines verbatim
            print line
            continue
        else:
            # split the line into key and value
            quote = line.find('"')
            key = line[:quote].strip()
            value = line[quote+1:]
    else:
        # line is a continuation of the previous value
        value += line
    # look for terminating quote
    quote = value.rfind('"')
    if quote != -1 and value[quote-1] != '\\':
        # non-escaped quote found
        # look for line-end comment
        pound = value.find('#', quote)
        if pound != -1:
            # print line-end comment before the property
            print value[pound:]

        # print the property key/value pair
        print key + '=' + value[:quote]
        key = None
    else:
        # value continues for another line
        value += '\\n'



#!/usr/bin/env python

# Convert from java properties file into XaoS catalog file

import fileinput

key = None
for line in fileinput.input():
    line = line.strip('\r\n')
    strip = line.strip()
    if len(strip) == 0 or strip.startswith('#'):
        # print blank lines and comments verbatim
        print line
    else:
        # otherwise this should be a key/value pair
        equal = line.find("=")
        if equal == -1:
            # there shouldn't be any other lines without an equal, but oh well
            print line
        else:
            # this is a property line
            key = line[:equal].strip()
            value = line[equal+1:].replace('\\n', '\n')
            print key + ' "' + value + '"'
